gradient_plot: Plot cerebellar activation map as a function of cerebellar...

Description Usage Arguments Examples

View source: R/plot_cereb_grad.R

Description

The only function in this package is the plotting function 'gradient_plot'. With default parameters it plots activation in the cerebellar gradient-space, as published by Guell et al. (2018, eLife), however it is easy to use it for plotting with other brain gradients (at leasst two). This is a developer version, use with caution.

Usage

1
2
3
4
5
6
7
gradient_plot(map, gradient1 = file.path(root_file("data"),
  "wcresult_cerebellumonly_gradient1_suit.nii"),
  gradient2 = file.path(root_file("data"),
  "wcresult_cerebellumonly_gradient2_suit.nii"),
  template = file.path(root_file("data"), "SUIT.nii"), thr = 2.3,
  template.thr = 30, slices = c(20, 25, 30, 35, 40, 45, 50, 55, 60),
  save = F, outbase = "")

Arguments

map

activation map to be plotted

gradient1

first gradient (recommended to use the default)

gradient2

second gradient (recommended to use the default)

template

template (recommended to use the default)

thr

threhold for the activation map

template.thr

template threshold (recommended to use the default)

slices

slices to save on the SUIT-space plot

outbase

filebase, withoput extenson

Examples

1
2
3
map=file.path("example", "spmT_0002_LinearTrend_CSm_gt_baseline.nii")
gradient_plot(map)
gradient_plot(map, save=T, outbase="test")

spisakt/gradientplot documentation built on Jan. 3, 2020, 12:17 a.m.